@@ -9,14 +9,15 @@ import re
 from collections import namedtuple
 from datetime import datetime
 from enum import Enum
+from itertools import chain
 from logging import getLogger
 from typing import Any, Dict, Iterable, Iterator, List, Optional, Tuple
 
 from pytz import timezone
 from requests import RequestException
 
-from . import FetcherException
 from .download import HTTP_SESSION, get_url
+from .errors import FetcherException
 
 LOG = getLogger("fuzzfetch")
 
@@ -151,16 +152,22 @@ class BuildTask:
             if branch not in {"autoland", "try"}:
                 branch = f"mozilla-{branch}"
 
+            namespaces = []
             if not any(flags):
                 # Opt builds are now indexed under 'shippable'
-                namespace = f"gecko.v2.{branch}.shippable.latest"
-            else:
-                namespace = f"gecko.v2.{branch}.latest"
+                namespaces.append(f"gecko.v2.{branch}.shippable.latest")
+            namespaces.append(f"gecko.v2.{branch}.latest")
 
             prod = "mobile" if "android" in target_platform else "firefox"
-            task_paths = (
-                f"/task/{namespace}.{prod}.{target_platform}{flags.build_string()}",
-                f"/task/{namespace}.{prod}.sm-{target_platform}{flags.build_string()}",
+            suffix = f"{target_platform}{flags.build_string()}"
+            task_paths = tuple(
+                chain.from_iterable(
+                    (
+                        f"/task/{namespace}.{prod}.{suffix}",
+                        f"/task/{namespace}.{prod}.sm-{suffix}",
+                    )
+                    for namespace in namespaces
+                )
             )
             task_template_paths = itertools.product((cls.TASKCLUSTER_API,), task_paths)
 
@@ -297,14 +304,25 @@ class Platform:
     """Class representing target OS and CPU, and how it maps to a Gecko mozconfig"""
 
     SUPPORTED = {
-        "Darwin": {"x86_64": "macosx64"},
-        "Linux": {"x86_64": "linux64", "x86": "linux"},
-        "Windows": {"x86_64": "win64", "arm64": "win64-aarch64"},
+        "Darwin": {
+            "arm64": "macosx64-aarch64",
+            "x86_64": "macosx64",
+        },
+        "Linux": {
+            "arm64": "linux64-aarch64",
+            "x86": "linux",
+            "x86_64": "linux64",
+        },
+        "Windows": {
+            "arm64": "win64-aarch64",
+            "x86": "win32",
+            "x86_64": "win64",
+        },
         "Android": {
-            "x86_64": "android-x86_64",
-            "x86": "android-x86",
             "arm": "android-api-16",
             "arm64": "android-aarch64",
+            "x86": "android-x86",
+            "x86_64": "android-x86_64",
         },
     }
     CPU_ALIASES = {
