@@ -4,11 +4,33 @@
 # You can obtain one at http://mozilla.org/MPL/2.0/.
 
 import tarfile
+import zipfile
 from unittest.mock import patch
 
 import pytest  # pylint: disable=import-error
 
-from fuzzfetch.extract import extract_tar
+from fuzzfetch.extract import extract_tar, extract_zip
+
+
+def test_zipfile_extract(tmp_path):
+    """basic extract_zip functions"""
+    (tmp_path / "empty").touch()
+    (tmp_path / "folder").mkdir()
+    with zipfile.ZipFile(tmp_path / "test.zip", "w") as zip_fp:
+        zip_fp.write(tmp_path / "empty", "./firefox/firefox")
+        zip_fp.write(tmp_path / "empty", "buildinfo.txt")
+        zip_fp.write(tmp_path / "folder", "folder")
+
+    (tmp_path / "out").mkdir()
+    extract_zip(tmp_path / "test.zip", tmp_path / "out")
+    assert set((tmp_path / "out").glob("**/*")) == {
+        tmp_path / "out" / "firefox",
+        tmp_path / "out" / "folder",
+        tmp_path / "out" / "buildinfo.txt",
+    }
+    assert (tmp_path / "out" / "firefox").is_file()
+    assert (tmp_path / "out" / "folder").is_dir()
+    assert (tmp_path / "out" / "buildinfo.txt").is_file()
 
 
 @patch("fuzzfetch.extract.TAR_PATH", None)
